@@ -28,15 +28,12 @@ obj = X[0] * X[1] + X[1] * X[0]
 # Inequality constraints
 inequalities = [-X[1] ** 2 + X[1] + 0.5]
 
-# Equality constraints
-equalities = []
-
 # Simple monomial substitutions
-monomial_substitutions = {}
-monomial_substitutions[X[0] ** 2] = X[0]
+monomial_substitution = {}
+monomial_substitution[X[0] ** 2] = X[0]
 
 # Obtain SDP relaxation
 sdpRelaxation = SdpRelaxation(X)
-sdpRelaxation.get_relaxation(obj, inequalities, equalities,
-                             monomial_substitutions, level)
+sdpRelaxation.get_relaxation(level, objective=obj, inequalities=inequalities,
+                             substitutions=monomial_substitution)
 write_to_sdpa(sdpRelaxation, 'example_commutative.dat-s')
