@@ -12,7 +12,7 @@ Created on Fri May 10 09:45:11 2013
 @author: Peter Wittek
 """
 
-from ncpol2sdpa import generate_variables, SdpRelaxation
+from ncpol2sdpa import generate_variables, SdpRelaxation, convert_to_picos
 
 # Number of Hermitian variables
 n_vars = 2
@@ -31,12 +31,11 @@ inequalities = [-X[1] ** 2 + X[1] + 0.5]
 # Equality constraints
 equalities = []
 equalities.append(X[0] ** 2 - X[0])
-# Simple monomial substitutions
-monomial_substitution = {}
-#monomial_substitution[X[0] ** 2] = X[0]
 
 # Obtain SDP relaxation
 sdpRelaxation = SdpRelaxation(X)
-P = sdpRelaxation.get_relaxation(obj, inequalities, equalities,
-                                 monomial_substitution, level, target='picos')
-P.solve(solver='mosek7')
+sdpRelaxation.get_relaxation(level, objective=obj,
+                             inequalities=inequalities,
+                             equalities=equalities)
+P = convert_to_picos(sdpRelaxation)
+P.solve()
