@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-The module contains helper functions to work with noncommutative polynomials
+This file contains helper functions to work with noncommutative polynomials
 and Hamiltonians.
 
 Created on Thu May  2 16:03:05 2013
@@ -18,10 +18,18 @@ if sys.version.find("PyPy") == -1:
 
 def flatten(lol):
     """Flatten a list of lists to a list.
+
+    :param lol: A list of lists in arbitrary depth.
+    :type lol: list of list.
+
+    :returns: flat list of elements.
     """
     new_list = []
     for element in lol:
-        if isinstance(element, Symbol) or isinstance(element, Operator):
+        if element == None or (isinstance(element, list) and len(element) == 0):
+            continue
+        elif isinstance(element, Symbol) or isinstance(element, Operator) or\
+          isinstance(element, int):
             new_list.append(element)
         elif isinstance(element[0], list):
             element = flatten(element)
@@ -94,6 +102,32 @@ def remove_scalar_factor(monomial):
     return monomial
 
 
+def get_support(variables, polynomial):
+    """Gets the support of a polynomial.
+    """
+    support = []
+    if isinstance(polynomial, (int, float, complex)):
+        support.append([0] * len(variables))
+        return support
+    polynomial = polynomial.expand()
+    for monomial in polynomial.as_coefficients_dict():
+        tmp_support = [0] * len(variables)
+        monomial, scalar = separate_scalar_factor(monomial)
+        symbolic_support = flatten(split_commutative_parts(monomial))
+        for s in symbolic_support:
+            if isinstance(s, Pow):
+                base = s.base
+                if isinstance(base, Dagger):
+                    base = Dagger(base)
+                tmp_support[variables.index(base)] = s.exp
+            elif isinstance(s, Dagger):
+                tmp_support[variables.index(Dagger(s))] = 1
+            elif isinstance(s, Operator):
+                tmp_support[variables.index(s)] = 1
+        support.append(tmp_support)
+    return support
+
+
 def build_monomial(element):
     """Construct a monomial with the coefficient separated
     from an element in a polynomial.
@@ -121,12 +155,11 @@ def count_ncmonomials(monomials, degree):
     or less. The function is useful when certain monomials were eliminated
     from the basis.
 
-    Arguments:
-    variables -- the noncommutative variables making up the monomials
-    monomials -- the list of monomials (the monomial basis)
-    degree -- maximum degree to count
+    :param variables: The noncommutative variables making up the monomials
+    :param monomials: List of monomials (the monomial basis).
+    :param degree:  Maximum degree to count.
 
-    Returns the count of appropriate monomials.
+    :returns: The count of appropriate monomials.
     """
     ncmoncount = 0
     for monomial in monomials:
@@ -142,10 +175,9 @@ def fast_substitute(monomial, old_sub, new_sub):
     cases of noncommutative algebras. In rare cases, it fails to find a
     substitution. Use it with proper testing.
 
-    Arguments:
-    monomial -- the monomial with parts need to be substituted
-    old_sub -- the part to be replaced
-    new_sub -- the replacement
+    :param monomial: The monomial with parts need to be substituted.
+    :param old_sub: The part to be replaced.
+    :param new_sub: The replacement.
     """
     if isinstance(monomial, Number):
         return monomial
@@ -253,12 +285,14 @@ def fast_substitute(monomial, old_sub, new_sub):
 
 
 def generate_variables(n_vars, hermitian=False, commutative=False, name='x'):
-    """Generates a number of noncommutative variables
+    """Generates a number of commutative or noncommutative variables
 
-    Arguments:
-    n_vars -- the number of variables
+    :param n_vars: The number of variables.
+    :type n_vars: int.
 
-    Returns a list of noncommutative variables
+    :returns: list of :class:`sympy.physics.quantum.operator.Operator` or
+              :class:`sympy.physics.quantum.operator.HermitianOperator`
+              variables
     """
 
     variables = []
@@ -274,11 +308,13 @@ def generate_variables(n_vars, hermitian=False, commutative=False, name='x'):
 def get_ncmonomials(variables, degree):
     """Generates all noncommutative monomials up to a degree
 
-    Arguments:
-    variables -- the noncommutative variables to generate monomials from
-    degree -- the maximum degree
+    :param variables: The noncommutative variables to generate monomials from
+    :type variables: list of :class:`sympy.physics.quantum.operator.Operator` or
+                     :class:`sympy.physics.quantum.operator`.
+    :param degree: The maximum degree.
+    :type degree: int.
 
-    Returns a list of monomials
+    :returns: list of monomials.
     """
     if not variables:
         return [S.One]
@@ -312,7 +348,13 @@ def get_variables_of_polynomial(polynomial):
 
 
 def ncdegree(polynomial):
-    """Returns the degree of a noncommutative polynomial."""
+    """Returns the degree of a noncommutative polynomial.
+
+    :param polynomial: Polynomial of noncommutive variables.
+    :type polynomial: :class:`sympy.core.expr.Expr`.
+
+    :returns: int -- the degree of the polynomial.
+    """
     degree = 0
     if isinstance(polynomial, (int, float, complex)):
         return degree
@@ -329,16 +371,16 @@ def ncdegree(polynomial):
     return degree
 
 
-def get_monomials(variables, extramonomials, monomial_substitutions, degree):
+def get_monomials(variables, extramonomials, substitutions, degree):
     """Return the monomials of a certain degree.
     """
     monomials = get_ncmonomials(variables, degree)
     if extramonomials is not None:
         monomials.extend(extramonomials)
     monomials = [monomial for monomial in monomials if monomial not
-                 in monomial_substitutions]
+                 in substitutions]
     monomials = [remove_scalar_factor(apply_substitutions(monomial,
-                                                          monomial_substitutions))
+                                                          substitutions))
                  for monomial in monomials]
     monomials = unique(monomials)
     return monomials
@@ -363,11 +405,11 @@ def pick_monomials_of_degree(monomials, degree):
     return selected_monomials
 
 
-def save_monomial_dictionary(filename, monomial_dictionary, n_vars):
+def save_monomial_index(filename, monomial_index, n_vars):
     """Save a monomial dictionary for debugging purposes.
     """
     monomial_translation = [''] * (n_vars + 1)
-    for key, k in monomial_dictionary.items():
+    for key, k in monomial_index.items():
         monomial = ('%s' % key)
         monomial = monomial.replace('Dagger(', '')
         monomial = monomial.replace(')', 'T')
